//------------------------------------------------------------------------------
// Lamp : Open source game middleware
// Copyright (C) 2004  Junpei Ohtani ( Email : junpee@users.sourceforge.jp )
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//------------------------------------------------------------------------------

/** @file
 * 変換シーンノードマネージャヘッダ
 * @author Junpee
 */

#ifndef TRANSLATION_SCENE_NODE_MANAGER_H_
#define TRANSLATION_SCENE_NODE_MANAGER_H_

#include <Core/Container/HashMap.h>
#include <Core/Container/ArrayList.h>
#include <Translator/SceneNode/TranslationSceneNode.h>

namespace LampForMaya{

class TranslationModelManager;

//------------------------------------------------------------------------------
/**
 * 変換シーンノードマネージャ
 */
class TranslationSceneNodeManager{
public:
	/**
	 * コンストラクタ
	 */
	TranslationSceneNodeManager();

	/**
	 * デストラクタ
	 */
	virtual ~TranslationSceneNodeManager();

	/**
	 * シーンノードの収集
	 * @return 成功すればtrue
	 */
	virtual bool collectSceneNodes();

	/**
	 * ピボットのコンパイル
	 * @param modelManager モデルマネージャ
	 * @return 成功すればtrue
	 */
	virtual bool compilePivot(TranslationModelManager* modelManager);

	/**
	 * アニメーションの収集
	 * @return 成功すればtrue
	 */
	virtual bool collectAnimations();

	/**
	 * Lampへの変換
	 * @param scene 変換先シーン
	 * @return 成功すればtrue
	 */
	virtual bool convertToLamp(Scene* scene) const;

	/**
	 * アニメーションの変換
	 * @param animationManager アニメーションマネージャ
	 * @param animationSet アニメーションセット
	 * @return 成功すればtrue
	 */
	virtual bool convertAnimation(
		AnimationManager* animationManager, AnimationSet* animationSet);

	/**
	 * クリア
	 * @return 削除したオブジェクト数
	 */
	virtual int clear();

	/**
	 * シーンノード数の取得
	 * @return シーンノード数
	 */
	virtual int getCount() const{ return array_.getCount(); }

	/**
	 * シーンノードの取得
	 * @param index シーンノードのインデクス
	 * @return シーンノード
	 */
	virtual TranslationSceneNode* get(int index) const{
		return array_.get(index);
	}

	/**
	 * シーンノードの検索
	 * @param name 検索するシーンノード名
	 * @return シーンノード
	 */
	virtual TranslationSceneNode* search(String name) const{
		return database_.get(name);
	}

	/**
	 * 有効Dagノードチェック
	 * @param dagPath Dagパス
	 * @return 有効なDagノードならtrue
	 */
	static bool checkValidDagNode(const MDagPath& dagPath);

protected:
	/**
	 * シーンノードの解析
	 * @param dagPath DAGパス
	 */
	virtual bool analysisSceneNode(MDagPath dagPath);

private:
	// コピーコンストラクタの隠蔽
	TranslationSceneNodeManager(const TranslationSceneNodeManager& copy);

	// 代入コピーの隠蔽
	void operator =(const TranslationSceneNodeManager& copy);

	// シーンノードデータベース
	Lamp::HashMap<String, TranslationSceneNode*> database_;
	// シーンノード配列
	ArrayList<TranslationSceneNode*> array_;

};

//------------------------------------------------------------------------------
} // End of namespace LampForMaya
#endif // End of TRANSLATION_SCENE_NODE_MANAGER_H_
//------------------------------------------------------------------------------
